﻿using System;
using System.Data.SQLite;
using System.IO;
using System.Text;
using System.Collections.Generic;
using System.Linq;
using FluentNHibernate.Cfg;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using NHibernate;
using NHibernate.Cfg;
using NHibernate.Linq;
using NHibernate.Tool.hbm2ddl;

namespace NHibernateTest.Test
{
    [TestClass]
    public class TestCanQueryByByte
    {
        private static Configuration cfg;
        private static ISessionFactory sessionFactory;
        private static SQLiteConnection masterConnection;

        [TestInitialize]
        public void TestInit()
        {
            const string CONNECTION_STRING = NHibernateConstantsTest.CONNECTION_STRING;

            var nhibernateConfig = new Configuration();
            nhibernateConfig.Configure(NHibernateConstantsTest.CONFIG_FILE);

            IDictionary<string, string> props = new Dictionary<string, string>
                {
                    {NHibernateConstantsTest.CONNECTION_STRING_PROPERTY, CONNECTION_STRING}
                };
            nhibernateConfig.AddProperties(props);

            var fluentConfig = Fluently.Configure(nhibernateConfig);
            fluentConfig.Mappings(m => m.FluentMappings.AddFromAssembly(typeof(MyEntity).Assembly));
            cfg = fluentConfig.BuildConfiguration();
            sessionFactory = cfg.BuildSessionFactory();

            masterConnection = new SQLiteConnection(CONNECTION_STRING);
            masterConnection.Open();

            var schemaExport = new SchemaExport(cfg);
            schemaExport.Execute(false, true, false, masterConnection, TextWriter.Null);
        }

        [TestMethod]
        public void Should_be_able_to_query_by_byte_type()
        {
            using (var session = sessionFactory.OpenSession(masterConnection))
            {
                (from e in session.Query<MyEntity>()
                 where e.MyByteProperty == 1 // FAILS
                 select e)
                .ToList();
            }
        }

        [TestMethod]
        public void Should_be_able_to_query_by_int_type()
        {
            using (var session = sessionFactory.OpenSession(masterConnection))
            {
                (from e in session.Query<MyEntity>()
                 where e.MyIntProperty == 1 // PASSES
                 select e)
                .ToList();
            }
        }
    }
}
